#include <avr/io.h>
#include <avr/interrupt.h>

#define F_CPU 16000000L
#include <util/delay.h>

/*
 * Initializes input and output ports.
 */
void init_ports(void)
{	
	/* PORTA input */
	DDRA = 0x00;
	PORTA = 0xFF;
	
	/* PORTD output */
	DDRD = 0xFF;
	PORTD = 0x00;
	
	TCCR1A |= _BV(COM1A1) | _BV(COM1B1) | _BV(WGM11); //NON Inverted PWM
    TCCR1B |= _BV(WGM13) | _BV(WGM12) | _BV(CS11) | _BV(CS10); //PRESCALER=64 MODE 14(FAST PWM)

}

int main(void)
{
	int i;
	int sen_val;
	
	init_ports();

	/* enable interrupts */
	sei();
	
	/* PWM fill-rate set to 50% */
	OCR1A = 65535 / 2;
	OCR1B = 65535 / 2;
	
    while (1) {
		sen_val = 0;
		
		/* acquire input from the sensors */
		for (i = 0; i < 8; i++)
			sen_val |= (((1 << i) & PINA) >> i) << (7 - i);
	
		/* drive the motors based on the sensors input */

		if (PINA - sen_val >= (1 << 4)) {
			PORTD = _BV(PD3);
		}
		else if (sen_val - PINA > (1 << 4)) {
			PORTD = _BV(PD6);
		}
		else {
			PORTD = _BV(PD6) | _BV(PD3);
		}

		_delay_ms(10);
    }

	return 0;
}